@@ -33,12 +33,13 @@
 
 #include <panel-applet.h>
 #include <gdk/gdkkeysyms.h>
-#include <libgnomeui/gnome-about.h>
+#include <libgnomeui/libgnomeui.h>
 
 #define WNCK_I_KNOW_THIS_IS_UNSTABLE
 #include <libwnck/libwnck.h>
 
 #include "inlinepixbufs.h"
+#include "eel/eel-ellipsizing-label.h"
 #include "egg-screen-help.h"
 #include "wncklet.h"
 
@@ -55,6 +56,8 @@ typedef struct {
 	GHashTable   *window_hash;
 
 	int           size;
+
+	GnomeIconTheme *icon_theme;
 } WindowMenu;
 
 static void window_menu_connect_to_window (WindowMenu *window_menu,
@@ -120,9 +123,9 @@ window_menu_about (BonoboUIComponent *uic,
 		return;
 	}
 
-	file = gnome_program_locate_file (
-			NULL, GNOME_FILE_DOMAIN_PIXMAP,
-			"gnome-windows.png", TRUE, NULL);
+	file = gnome_icon_theme_lookup_icon (window_menu->icon_theme,
+					     "panel-window-menu",
+					     48, NULL, NULL);
 	pixbuf = gdk_pixbuf_new_from_file (file, NULL);
 	g_free (file);
 
@@ -130,7 +133,7 @@ window_menu_about (BonoboUIComponent *uic,
 				 "Copyright \xc2\xa9 2003 Sun Microsystems, Inc.\n"
 				 "Copyright \xc2\xa9 2001 Free Software Foundation, Inc.\n"
 				 "Copyright \xc2\xa9 2000 Helix Code, Inc.",
-				 _("The Window List shows a list of all visible windows and lets you browse them."),
+				 _("The Window Menu shows a list of all windows and lets you browse them."),
 				 authors,
 				 documenters,
 				 strcmp (translator_credits, "translator_credits") != 0 ? translator_credits : NULL,
@@ -169,6 +172,10 @@ window_menu_destroy (GtkWidget  *widget,
 		g_object_unref (window_menu->icon_pixbuf);
 	window_menu->icon_pixbuf = NULL;
 
+	if (window_menu->icon_theme)
+		g_object_unref (window_menu->icon_theme);
+        window_menu->icon_theme = NULL;
+
 	if (window_menu->no_windows_item)
 		g_object_unref (window_menu->no_windows_item);
 	window_menu->no_windows_item = NULL;
@@ -328,6 +335,63 @@ window_menu_activate_window (WnckWindow *window)
 	wnck_window_activate (window);
 }
 
+#define WINDOW_MENU_MAX_WIDTH 50	/* maximum width in characters */
+
+static gint
+get_width (GtkWidget *widget, const char *text)
+{
+	PangoContext *context;
+	PangoFontMetrics *metrics;
+	gint char_width;
+	PangoLayout *layout;
+	PangoRectangle natural;
+	gint max_width;
+	gint screen_width;
+	gint width;
+
+	gtk_widget_ensure_style (widget);
+
+	context = gtk_widget_get_pango_context (widget);
+	metrics = pango_context_get_metrics (
+		context, widget->style->font_desc,
+		pango_context_get_language (context));
+	char_width = pango_font_metrics_get_approximate_char_width (metrics);
+	pango_font_metrics_unref (metrics);
+	max_width = PANGO_PIXELS (WINDOW_MENU_MAX_WIDTH * char_width);
+
+	layout = gtk_widget_create_pango_layout (widget, text);
+	pango_layout_get_pixel_extents (layout, NULL, &natural);
+	g_object_unref (G_OBJECT (layout));
+
+	screen_width = gdk_screen_get_width (gtk_widget_get_screen (widget));
+
+	width = MIN (natural.width, max_width);
+	width = MIN (width, 3 * (screen_width / 4));
+	
+	return width;
+}
+
+static GtkWidget*
+window_menu_item_new (WindowMenu  *window_menu,
+		      const gchar *label)
+{
+	GtkWidget *item;
+	GtkWidget *ellipsizing_label;
+
+	item = gtk_image_menu_item_new ();
+	
+	ellipsizing_label = eel_ellipsizing_label_new (label);
+	gtk_misc_set_alignment (GTK_MISC (ellipsizing_label), 0.0, 0.5);
+
+	gtk_container_add (GTK_CONTAINER (item), ellipsizing_label);
+
+	gtk_widget_show (ellipsizing_label);
+
+	gtk_widget_set_size_request (
+		ellipsizing_label, get_width (window_menu->applet, label), -1);
+	return item;
+}
+
 static void
 window_menu_add_window (WindowMenu *window_menu,
 			WnckWindow *window)
@@ -353,7 +417,7 @@ window_menu_add_window (WindowMenu *window_menu,
 		freeme = label;
 	}
 
-	item = gtk_image_menu_item_new_with_label (label);
+	item = window_menu_item_new (window_menu, label);
 	if (freeme)
 		g_free (freeme);
 
@@ -545,7 +609,9 @@ window_menu_popup_menu (WindowMenu *window_menu,
 	}
 
 	if (!l) {
-		window_menu->no_windows_item = gtk_menu_item_new_with_label (_("No Windows Open"));
+		window_menu->no_windows_item = window_menu_item_new (
+							window_menu,
+							_("No Windows Open"));
 
 		gtk_widget_set_sensitive (window_menu->no_windows_item, FALSE);
 		gtk_widget_show (window_menu->no_windows_item);	
@@ -633,10 +699,12 @@ window_menu_applet_fill (PanelApplet *applet)
 	window_menu->applet = GTK_WIDGET (applet);
 	atk_obj = gtk_widget_get_accessible (window_menu->applet);
 	atk_object_set_name (atk_obj, _("Window Menu"));
-	atk_object_set_description (atk_obj, "Tool to switch between windows");
+	atk_object_set_description (atk_obj, _("Tool to switch between windows"));
 
 	panel_applet_set_flags (applet, PANEL_APPLET_EXPAND_MINOR);
 
+        window_menu->icon_theme = gnome_icon_theme_new ();
+
 	g_signal_connect (window_menu->applet, "destroy",
 			  G_CALLBACK (window_menu_destroy), window_menu);
 
