@@ -317,7 +317,6 @@ create_drawer_applet (PanelToplevel    *toplevel,
 		      PanelOrientation  orientation)
 {
 	Drawer *drawer;
-	AtkObject *atk_obj;
 	
 	drawer = g_new0 (Drawer, 1);
 
@@ -336,9 +335,6 @@ create_drawer_applet (PanelToplevel    *toplevel,
 		return NULL;
 	}
 
-	atk_obj = gtk_widget_get_accessible (drawer->button);
-	atk_object_set_name (atk_obj, "Drawer"); 
-
 	if (tooltip && tooltip [0]) {
 		panel_toplevel_set_name (toplevel, tooltip);
 		gtk_tooltips_set_tip (panel_tooltips, drawer->button, tooltip, NULL);
@@ -591,7 +587,7 @@ load_drawer_applet (char          *toplevel_id,
 	panel_widget_set_applet_expandable (panel_widget, GTK_WIDGET (drawer->button), FALSE, TRUE);
 	panel_widget_set_applet_size_constrained (panel_widget, GTK_WIDGET (drawer->button), TRUE);
 
-	if (!commie_mode)
+	if ( ! panel_profile_get_locked_down ())
 		panel_applet_add_callback (drawer->info,
 					   "properties",
 					   GTK_STOCK_PROPERTIES,
