@@ -85,10 +85,15 @@ panel_action_lock_setup_menu (PanelActionButton *button)
 {
 	panel_applet_add_callback (button->priv->info, "activate", NULL, _("_Activate Screensaver"));
 	panel_applet_add_callback (button->priv->info, "lock",     NULL, _("_Lock Screen"));
-	panel_applet_add_callback (button->priv->info, "exit",     NULL, _("_Kill Screensaver Daemon"));
+
+	/* in commie mode don't allow killing the screensaver */
+	if ( ! panel_profile_get_locked_down ())
+		panel_applet_add_callback (button->priv->info, "exit",     NULL, _("_Kill Screensaver Daemon"));
+
 	panel_applet_add_callback (button->priv->info, "restart",  NULL, _("Restart _Screensaver Daemon"));
 
-	if (!commie_mode)
+	/* in commie mode don't allow changing the screensaver properties */
+	if ( ! panel_profile_get_locked_down ())
 		panel_applet_add_callback (button->priv->info, "prefs", NULL, _("_Properties"));
 }
 
@@ -139,6 +144,9 @@ panel_action_logout (GtkWidget *widget)
 void
 panel_action_run_program (GtkWidget *widget)
 {
+	if (panel_profile_get_inhibit_command_line ())
+		return;
+
 	panel_run_dialog_present (gtk_widget_get_screen (widget));
 }
 
@@ -185,6 +193,9 @@ panel_action_force_quit (GtkWidget *widget)
 {
 	GdkScreen *screen;
 
+	if (panel_profile_get_inhibit_force_quit ())
+		return;
+
 	screen = gtk_widget_get_screen (widget);
 
 	panel_force_quit (screen);
@@ -391,7 +402,7 @@ panel_action_button_class_init (PanelActionButtonClass *klass,
 			gobject_class,
 			PROP_DND_ENABLED,
 			g_param_spec_boolean ("dnd-enabled",
-					      _("Drag N' Drop enabled"),
+					      _("Drag and drop enabled"),
 					      _("Whether or not drag and drop is enabled on the widget"),
 					      TRUE,
 					      G_PARAM_READWRITE));
