@@ -50,6 +50,7 @@
 #define PROPERTY_BACKGROUND "panel-applet-background"
 #define PROPERTY_FLAGS      "panel-applet-flags"
 #define PROPERTY_SIZE_HINTS "panel-applet-size-hints"
+#define PROPERTY_LOCKED_DOWN "panel-applet-locked-down"
 
 
 struct _PanelAppletFramePrivate {
@@ -85,6 +86,7 @@ static void
 panel_applet_frame_sync_menu_state (PanelAppletFrame *frame)
 {
 	PanelWidget *panel_widget;
+	gboolean     locked_down;
 	gboolean     locked;
 	gboolean     lockable;
 	gboolean     movable;
@@ -96,6 +98,9 @@ panel_applet_frame_sync_menu_state (PanelAppletFrame *frame)
 	movable = panel_applet_can_freely_move (frame->priv->applet_info);
 	removable = panel_profile_list_is_writable (PANEL_GCONF_APPLETS);
 
+	locked_down = panel_profile_get_locked_down () ||
+		panel_toplevel_get_locked_down (panel_widget->toplevel);
+
 	locked = panel_widget_get_applet_locked (panel_widget, GTK_WIDGET (frame));
 
 	bonobo_ui_component_set_prop (frame->priv->ui_component,
@@ -104,6 +109,7 @@ panel_applet_frame_sync_menu_state (PanelAppletFrame *frame)
 				      locked ? _("Un_lock") : _("_Lock"),
 				      NULL);
 
+	/* First sensitivity */
 	bonobo_ui_component_set_prop (frame->priv->ui_component,
 				      "/commands/LockAppletToPanel",
 				      "sensitive",
@@ -121,6 +127,25 @@ panel_applet_frame_sync_menu_state (PanelAppletFrame *frame)
 				      "sensitive",
 				      locked ? "0" : (movable ? "1" : "0"),
 				      NULL);
+
+	/* Second visibility */
+	bonobo_ui_component_set_prop (frame->priv->ui_component,
+				      "/commands/LockAppletToPanel",
+				      "hidden",
+				      locked_down ? "1" : "0",
+				      NULL);
+
+	bonobo_ui_component_set_prop (frame->priv->ui_component,
+				      "/commands/RemoveAppletFromPanel",
+				      "hidden",
+				      locked_down ? "1" : "0",
+				      NULL);
+
+	bonobo_ui_component_set_prop (frame->priv->ui_component,
+				      "/commands/MoveApplet",
+				      "hidden",
+				      locked_down ? "1" : "0",
+				      NULL);
 }
 
 static void
@@ -500,6 +525,28 @@ panel_applet_frame_expose (GtkWidget      *widget,
 	return FALSE;
 }
 
+static void
+panel_applet_frame_update_background_size (PanelAppletFrame *frame,
+					   GtkAllocation    *old_allocation,
+					   GtkAllocation    *new_allocation)
+{
+	PanelBackground *background;
+
+	if (old_allocation->x      == new_allocation->x &&
+	    old_allocation->y      == new_allocation->y &&
+	    old_allocation->width  == new_allocation->width &&
+	    old_allocation->height == new_allocation->height)
+		return;
+
+	background = &frame->priv->panel->background;
+
+	if (background->type == PANEL_BACK_NONE ||
+	   (background->type == PANEL_BACK_COLOR && !background->has_alpha))
+		return;
+
+	panel_applet_frame_change_background (frame, background->type);
+}
+
 static void
 panel_applet_frame_size_request (GtkWidget      *widget,
 				 GtkRequisition *requisition)
@@ -551,12 +598,22 @@ panel_applet_frame_size_allocate (GtkWidget     *widget,
 	PanelAppletFrame *frame;
 	GtkBin           *bin;
 	GtkAllocation     new_allocation;
+	GtkAllocation     old_allocation;
+
+	old_allocation.x      = widget->allocation.x;
+	old_allocation.y      = widget->allocation.y;
+	old_allocation.width  = widget->allocation.width;
+	old_allocation.height = widget->allocation.height;
 
 	frame = PANEL_APPLET_FRAME (widget);
 	bin = GTK_BIN (widget);
 
 	if (!frame->priv->has_handle) {
-		GTK_WIDGET_CLASS (parent_class)->size_allocate (widget, allocation);
+		GTK_WIDGET_CLASS (parent_class)->size_allocate (widget,
+								allocation);
+		panel_applet_frame_update_background_size (frame,
+							   &old_allocation,
+							   allocation);
 		return;
 	}
 
@@ -616,6 +673,10 @@ panel_applet_frame_size_allocate (GtkWidget     *widget,
 		gtk_widget_size_allocate (bin->child, &new_allocation);
   
 	frame->priv->child_allocation = new_allocation;
+
+	panel_applet_frame_update_background_size (frame,
+						   &old_allocation,
+						   allocation);
 }
 
 static inline gboolean
@@ -737,10 +798,6 @@ panel_applet_frame_reload_response (GtkWidget        *dialog,
 			panel_profile_delete_object (info);
 	}
 
-	 frame->priv->panel->open_dialogs = 
-					g_slist_remove (
-					frame->priv->panel->open_dialogs,
-					dialog);
 	g_object_unref (frame);
 	gtk_widget_destroy (dialog);
 }
@@ -788,6 +845,7 @@ panel_applet_frame_cnx_broken (PanelAppletFrame *frame)
 	GdkScreen *screen;
 	char      *applet_name = NULL;
 	char      *txt;
+	gboolean   locked;
 
 	g_return_if_fail (PANEL_IS_APPLET_FRAME (frame));
 
@@ -796,14 +854,20 @@ panel_applet_frame_cnx_broken (PanelAppletFrame *frame)
 	if (frame->priv->iid)
 		applet_name = panel_applet_frame_get_name (frame->priv->iid);
 
+	locked = panel_profile_get_locked_down () ||
+		panel_toplevel_get_locked_down (frame->priv->panel->toplevel);
+
 	txt = g_strdup_printf (
 			_("The %s applet appears to have died "
 			  "unexpectedly\n\n"
-			  "Reload this applet?\n\n"
+			  "Reload this applet?%s"),
+			  applet_name ? applet_name : "",
+			  locked ? "" :
+			  _("\n\n"
 			  "(If you choose not to reload it at this time"
 			  " you can always add it by right clicking on "
 			  "the panel and clicking on the \"Add to Panel\""
-			  " submenu)"), applet_name ? applet_name : "");
+			  " submenu)"));
 
 	dialog = gtk_message_dialog_new (
 				NULL,
@@ -817,10 +881,8 @@ panel_applet_frame_cnx_broken (PanelAppletFrame *frame)
 			  G_CALLBACK (panel_applet_frame_reload_response),
 			  g_object_ref (frame));
 
-	frame->priv->panel->open_dialogs 
-				= g_slist_append (
-					frame->priv->panel->open_dialogs,
-					dialog);
+	panel_widget_register_open_dialog (frame->priv->panel, dialog);
+
 	gtk_widget_show (dialog);
 	g_free (applet_name);
 	g_free (txt);
@@ -853,6 +915,11 @@ register_stock_item (void)
         }
 }
 
+enum {
+	LOADING_FAILED_RESPONSE_DONT_DELETE,
+	LOADING_FAILED_RESPONSE_DELETE
+};
+
 static void
 panel_applet_frame_loading_failed (PanelAppletFrame  *frame,
 				   CORBA_Environment *ev,
@@ -862,35 +929,50 @@ panel_applet_frame_loading_failed (PanelAppletFrame  *frame,
 {
 	GtkWidget *dialog;
 	int        response;
+	gboolean   locked;
+
+	locked = panel_profile_get_locked_down () ||
+		panel_toplevel_get_locked_down (frame->priv->panel->toplevel);
 
 	if (ev != NULL) {
 		char *error = bonobo_exception_get_text (ev);
 		dialog = gtk_message_dialog_new (
 					NULL, 0,
-					GTK_MESSAGE_QUESTION,
+					locked ? GTK_MESSAGE_INFO : GTK_MESSAGE_QUESTION,
 					GTK_BUTTONS_NONE,
 					_("The panel encountered a problem while loading \"%s\"\n"
-					  "Details: %s\n\n"
-					  "Do you want to delete the applet from your configuration?"),
-					iid, error);
+					  "Details: %s%s"),
+					iid, error,
+					locked ? "" :
+					_("\n\n"
+					  "Do you want to delete the applet from your configuration?"));
 		g_free (error);
 	} else {
 		dialog = gtk_message_dialog_new (
 					NULL, 0,
-					GTK_MESSAGE_QUESTION,
+					locked ? GTK_MESSAGE_INFO : GTK_MESSAGE_QUESTION,
 					GTK_BUTTONS_NONE,
-					_("The panel encountered a problem while loading \"%s\"\n\n"
-					  "Do you want to delete the applet from your configuration?"),
-					iid);
+					_("The panel encountered a problem while loading \"%s\"%s"),
+					iid,
+					locked ? "" :
+					_("\n\n"
+					  "Do you want to delete the applet from your configuration?"));
 	}
 
 	register_stock_item ();
 
-	gtk_dialog_add_buttons (GTK_DIALOG (dialog),
-				PANEL_STOCK_DONT_DELETE, GTK_RESPONSE_CANCEL,
-				GTK_STOCK_DELETE, GTK_RESPONSE_OK,
-				NULL);
-	gtk_dialog_set_default_response (GTK_DIALOG (dialog), GTK_RESPONSE_OK);
+	if (locked) {
+		gtk_dialog_add_buttons (GTK_DIALOG (dialog),
+					GTK_STOCK_OK, LOADING_FAILED_RESPONSE_DONT_DELETE,
+					NULL);
+		gtk_dialog_set_default_response (GTK_DIALOG (dialog), LOADING_FAILED_RESPONSE_DONT_DELETE);
+	} else {
+		gtk_dialog_add_buttons (GTK_DIALOG (dialog),
+					PANEL_STOCK_DONT_DELETE, LOADING_FAILED_RESPONSE_DONT_DELETE,
+					GTK_STOCK_DELETE, LOADING_FAILED_RESPONSE_DELETE,
+					NULL);
+		gtk_dialog_set_default_response (GTK_DIALOG (dialog), LOADING_FAILED_RESPONSE_DELETE);
+	}
 
 	gtk_window_set_screen (GTK_WINDOW (dialog),
 			       gtk_window_get_screen (panel));
@@ -899,11 +981,12 @@ panel_applet_frame_loading_failed (PanelAppletFrame  *frame,
 
 	gtk_widget_destroy (dialog);
 
-	if (response == GTK_RESPONSE_OK) {
+	if (response == LOADING_FAILED_RESPONSE_DELETE) {
 		/* if we can't write to applets list we can't really delete
 		   it, so we'll just ignore this.  There's nothing we can
 		   do about it. */
-		if (panel_profile_list_is_writable (PANEL_GCONF_APPLETS))
+		if ( ! locked &&
+		    panel_profile_list_is_writable (PANEL_GCONF_APPLETS))
 			panel_profile_remove_from_list (PANEL_GCONF_APPLETS, id);
 	}
 }
@@ -1053,6 +1136,7 @@ panel_applet_frame_construct_moniker (PanelAppletFrame *frame,
 {
 	char *retval;
 	char *bg_str;
+	gboolean locked_down;
 
 	bg_str = panel_applet_frame_get_background_string (
 				frame, panel, panel->background.type);
@@ -1060,12 +1144,16 @@ panel_applet_frame_construct_moniker (PanelAppletFrame *frame,
 	if (bg_str == NULL)
 		bg_str = g_strdup ("");
 
+	locked_down = panel_profile_get_locked_down () ||
+		panel_toplevel_get_locked_down (panel->toplevel);
+
 	retval = g_strdup_printf (
 			"%s!prefs_key=/apps/panel/profiles/%s/applets/%s/prefs;"
-			"background=%s;orient=%s;size=%s",
+			"background=%s;orient=%s;size=%s;locked_down=%s",
 			iid, panel_profile_get_name (), id, bg_str,
 			panel_applet_frame_get_orient_string (frame, panel),
-			panel_applet_frame_get_size_string (frame, panel));
+			panel_applet_frame_get_size_string (frame, panel),
+			locked_down ? "true" : "false");
 
 	g_free (bg_str);
 
@@ -1098,9 +1186,19 @@ panel_applet_frame_construct (PanelAppletFrame *frame,
 	ORBitConnectionStatus  cnx_status;
 	GtkWidget             *widget;
 	char                  *moniker;
+	GSList                *disabled_applets;
 
 	frame->priv->panel = panel;
 
+	disabled_applets = panel_profile_get_disabled_applets ();
+
+	if (g_slist_find_custom (disabled_applets, iid, (GCompareFunc)strcmp) != NULL) {
+		panel_g_slist_deep_free (disabled_applets);
+		return NULL;
+	}
+
+	panel_g_slist_deep_free (disabled_applets);
+
 	moniker = panel_applet_frame_construct_moniker (frame, panel, iid, id);
 
 	/* FIXME: this should really use bonobo_get_object_async */
