@@ -105,21 +105,28 @@ panel_menu_bar_append_actions_menu (PanelMenuBar *menubar)
 
 	menubar->priv->actions_menu = panel_create_menu ();
 
+	/* intercept all right button clicks makes sure they don't
+	   go to the object itself */
+	g_signal_connect (G_OBJECT (menubar->priv->actions_menu), "button_press_event",
+			  G_CALLBACK (menu_dummy_button_press_event), NULL);
+
 	g_signal_connect (menubar->priv->actions_menu, "destroy",
 			  G_CALLBACK (gtk_widget_destroyed),
 			  &menubar->priv->actions_menu);
 
-	panel_menu_bar_append_action_item (
-			menubar,
-			menubar->priv->actions_menu,
-			_("Run Application..."),
-			PANEL_STOCK_RUN,
-			_("Run an Application by entering a command"),
-			"ACTION:run:NEW",
-			G_CALLBACK (panel_action_run_program));
+	if ( ! panel_profile_get_inhibit_command_line ()) {
+		panel_menu_bar_append_action_item (
+						   menubar,
+						   menubar->priv->actions_menu,
+						   _("Run Application..."),
+						   PANEL_STOCK_RUN,
+						   _("Run an Application by entering a command"),
+						   "ACTION:run:NEW",
+						   G_CALLBACK (panel_action_run_program));
 
-	item = gtk_separator_menu_item_new ();
-	gtk_menu_shell_append (GTK_MENU_SHELL (menubar->priv->actions_menu), item);
+		item = gtk_separator_menu_item_new ();
+		gtk_menu_shell_append (GTK_MENU_SHELL (menubar->priv->actions_menu), item);
+	}
 
 	if (panel_is_program_in_path  ("gnome-search-tool"))
 		panel_menu_bar_append_action_item (
@@ -188,12 +195,17 @@ panel_menu_bar_instance_init (PanelMenuBar      *menubar,
 	item = gtk_image_menu_item_new_with_label (_("Applications"));
         image = gtk_image_new_from_stock (
 			PANEL_STOCK_GNOME_LOGO,
-			panel_menu_bar_icon_get_size ()),
+			panel_menu_bar_icon_get_size ());
 	gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (item), image);
 
 	menubar->priv->applications_menu =
 		create_root_menu (NULL, NULL, TRUE, MENU_FLAGS, FALSE);
 
+	/* intercept all right button clicks makes sure they don't
+	   go to the object itself */
+	g_signal_connect (G_OBJECT (menubar->priv->applications_menu), "button_press_event",
+			  G_CALLBACK (menu_dummy_button_press_event), NULL);
+
 	g_signal_connect (menubar->priv->applications_menu, "destroy",
 			  G_CALLBACK (gtk_widget_destroyed),
 			  &menubar->priv->applications_menu);
@@ -359,11 +371,25 @@ panel_menu_bar_popup_menu (PanelMenuBar *menubar,
 			   guint32       activate_time)
 {
 	GtkMenu *menu;
+	GtkMenuShell *menu_shell;
 	
 	g_return_if_fail (PANEL_IS_MENU_BAR (menubar));
 
 	menu = GTK_MENU (menubar->priv->applications_menu);
 
-	gtk_menu_shell_select_item (GTK_MENU_SHELL (menubar),
+	/* 
+	 * We need to call _gtk_menu_shell_activate() here as is done in 
+	 * window_key_press_handler in gtkmenubar.c which pops up menu
+	 * when F10 is pressed.
+         *
+	 * As that function is private its code is replicated here.
+	 */
+	menu_shell = GTK_MENU_SHELL (menubar);
+	if (!menu_shell->active) {
+		gtk_grab_add (GTK_WIDGET (menu_shell));
+		menu_shell->have_grab = TRUE;
+		menu_shell->active = TRUE;
+	}
+	gtk_menu_shell_select_item (menu_shell,
 				    gtk_menu_get_attach_widget (menu));
 }
