@@ -148,7 +148,6 @@ panel_size_change (GtkWidget *widget, gpointer data)
 			      widget);
 }
 
-#ifdef FIXME_FOR_NEW_CONFIG
 void
 back_change (AppletInfo  *info,
 	     PanelWidget *panel)
@@ -181,7 +180,6 @@ panel_back_change (GtkWidget *widget, gpointer data)
 	update_config_back(PANEL_WIDGET(widget));
 #endif /* FIXME_FOR_NEW_CONFIG */
 }
-#endif
 
 static void
 panel_applet_added(GtkWidget *widget, GtkWidget *applet, gpointer data)
@@ -194,9 +192,7 @@ panel_applet_added(GtkWidget *widget, GtkWidget *applet, gpointer data)
 
 	orientation_change(info,PANEL_WIDGET(widget));
 	size_change(info,PANEL_WIDGET(widget));
-#ifdef FIXME_FOR_NEW_CONFIG
 	back_change(info,PANEL_WIDGET(widget));
-#endif
 }
 
 static void
@@ -337,7 +333,7 @@ panel_popup_menu (PanelToplevel *toplevel,
 			     gtk_window_get_screen (GTK_WINDOW (toplevel)));
 
 	gtk_menu_popup (GTK_MENU (menu), NULL, NULL,
-			panel_menu_position, toplevel, button, activate_time);
+			panel_menu_position, panel_widget, button, activate_time);
 
 	return TRUE;
 }
@@ -508,7 +504,7 @@ drop_directory (PanelWidget *panel, int pos, const char *dir)
 
 	if (panel_is_program_in_path ("nautilus")) {
 		/* nautilus */
-		return drop_nautilus_uri (panel, pos, dir, "gnome-folder.png");
+		return drop_nautilus_uri (panel, pos, dir, "gnome-fs-directory.png");
 	} else {
 		return drop_menu (panel, pos, dir);
 	}
@@ -861,6 +857,10 @@ panel_check_drop_forbidden (PanelWidget    *panel,
 	if (!panel)
 		return FALSE;
 
+	if (panel_toplevel_get_locked_down (panel->toplevel) ||
+	    panel_profile_get_locked_down ())
+		return FALSE;
+
 	if (info == TARGET_APPLET_INTERNAL) {
 		GtkWidget *source_widget;
 
@@ -959,6 +959,13 @@ panel_receive_dnd_data (PanelWidget      *panel,
 			guint             time_)
 {
 	gboolean success = FALSE;
+
+	if (panel_toplevel_get_locked_down (panel->toplevel) ||
+	    panel_profile_get_locked_down ()) {
+		gtk_drag_finish (context, FALSE, FALSE, time_);
+		return;
+	}
+
 	switch (info) {
 	case TARGET_URL:
 		success = drop_urilist (panel, pos, (char *)selection_data->data);
@@ -1066,12 +1073,10 @@ panel_widget_setup(PanelWidget *panel)
 			  "applet_move",
 			  G_CALLBACK(panel_applet_move),
 			  NULL);
-#ifdef FIXME_FOR_NEW_TOPLEVEL
 	g_signal_connect (G_OBJECT (panel),
 			  "back_change",
 			  G_CALLBACK (panel_back_change),
 			  NULL);
-#endif
 	g_signal_connect (G_OBJECT (panel),
 			  "size_change",
 			  G_CALLBACK (panel_size_change),
