@@ -68,14 +68,14 @@ struct _PanelAppletPrivate {
 	guint                       size;
 	char                       *background;
 
-	GdkPixmap                  *bg_pixmap;
-
         int                        *size_hints;
         int                         size_hints_len;
 
 	gboolean                    moving_focus_out;
 	int                         focusable_child;
 	guint                       hierarchy_changed_id;
+
+	gboolean                    locked_down;
 };
 
 static GObjectClass *parent_class;
@@ -96,6 +96,7 @@ static guint panel_applet_signals [LAST_SIGNAL];
 #define PROPERTY_BACKGROUND "panel-applet-background"
 #define PROPERTY_FLAGS      "panel-applet-flags"
 #define PROPERTY_SIZE_HINTS "panel-applet-size-hints"
+#define PROPERTY_LOCKED_DOWN "panel-applet-locked-down"
 
 enum {
 	PROPERTY_ORIENT_IDX,
@@ -103,6 +104,7 @@ enum {
 	PROPERTY_BACKGROUND_IDX,
 	PROPERTY_FLAGS_IDX,
 	PROPERTY_SIZE_HINTS_IDX,
+	PROPERTY_LOCKED_DOWN_IDX,
 };
 
 static void
@@ -291,6 +293,14 @@ panel_applet_get_orient (PanelApplet *applet)
 	return applet->priv->orient;
 }
 
+gboolean
+panel_applet_get_locked_down (PanelApplet *applet)
+{
+	g_return_val_if_fail (PANEL_IS_APPLET (applet), FALSE);
+
+	return applet->priv->locked_down;
+}
+
 void
 panel_applet_setup_menu (PanelApplet        *applet,
 			 const gchar        *xml,
@@ -371,6 +381,10 @@ panel_applet_finalize (GObject *object)
 	g_free (applet->priv->background);
 	g_free (applet->priv->iid);
 
+	if (applet->priv->closure)
+		g_closure_unref (applet->priv->closure);
+	applet->priv->closure = NULL;
+
 	g_free (applet->priv);
 	applet->priv = NULL;
 
@@ -688,6 +702,7 @@ panel_applet_focus (GtkWidget        *widget,
 			 */ 
 			GTK_WIDGET_SET_FLAGS (widget, GTK_CAN_FOCUS);
 			gtk_widget_grab_focus (widget);
+			GTK_WIDGET_UNSET_FLAGS (widget, GTK_CAN_FOCUS);
 			ret = TRUE;
 		}
 	}
@@ -763,24 +778,27 @@ panel_applet_get_pixmap (PanelApplet     *applet,
 			 int              x,
 			 int              y)
 {
-	GdkWindow *window;
-	GdkPixmap *retval;
-	GdkGC     *gc;
-	int        width;
-	int        height;
+	GdkPixmap  *pixmap;
+	GdkDisplay *display;
+	GdkPixmap  *retval;
+	GdkGC      *gc;
+	int         width;
+	int         height;
 
 	g_return_val_if_fail (PANEL_IS_APPLET (applet), NULL);
 
 	if (!GTK_WIDGET_REALIZED (applet))
 		return NULL;
 
-	window = gdk_window_lookup (xid);
-	if (window)
-		g_object_ref (window);
+	display = gdk_display_get_default ();
+	
+	pixmap = gdk_pixmap_lookup_for_display (display, xid);
+	if (pixmap)
+		g_object_ref (pixmap);
 	else
-		window = gdk_window_foreign_new (xid);
+		pixmap = gdk_pixmap_foreign_new_for_display (display, xid);
 
-	g_return_val_if_fail (window != NULL, NULL);
+	g_return_val_if_fail (pixmap != NULL, NULL);
 
 	gdk_drawable_get_size (GDK_DRAWABLE (GTK_WIDGET (applet)->window),
 			       &width, &height);
@@ -793,13 +811,13 @@ panel_applet_get_pixmap (PanelApplet     *applet,
 
 	gdk_draw_drawable (GDK_DRAWABLE (retval),
 			   gc, 
-			   GDK_DRAWABLE (window),
+			   GDK_DRAWABLE (pixmap),
 			   x, y,
 			   0, 0,
 			   width, height);
 
 	g_object_unref (gc);
-	g_object_unref (window);
+	g_object_unref (pixmap);
 
 	return retval;
 }
@@ -916,6 +934,9 @@ panel_applet_get_prop (BonoboPropertyBag *sack,
 			seq->_buffer [i] = applet->priv->size_hints [i];
 	}
 		break;
+	case PROPERTY_LOCKED_DOWN_IDX:
+		BONOBO_ARG_SET_BOOLEAN (arg, applet->priv->locked_down);
+		break;
 	default:
 		g_assert_not_reached ();
 		break;
@@ -1016,6 +1037,9 @@ panel_applet_set_prop (BonoboPropertyBag *sack,
 		applet->priv->size_hints_len = seq->_length;;
 	}
 		break;
+	case PROPERTY_LOCKED_DOWN_IDX:
+		applet->priv->locked_down = BONOBO_ARG_GET_BOOLEAN (arg);
+		break;
 	default:
 		g_assert_not_reached ();
 		break;
@@ -1071,6 +1095,14 @@ panel_applet_property_bag (PanelApplet *applet)
 				 _("Ranges that hint what sizes are acceptable for the applet"),
 				 Bonobo_PROPERTY_READABLE);
 
+	bonobo_property_bag_add (sack,
+				 PROPERTY_LOCKED_DOWN,
+				 PROPERTY_LOCKED_DOWN_IDX,
+				 BONOBO_ARG_BOOLEAN,
+				 NULL,
+				 _("The Applet's containing Panel is locked down"),
+				 Bonobo_PROPERTY_READABLE | Bonobo_PROPERTY_WRITEABLE);
+
 	return sack;
 }
 
@@ -1196,6 +1228,16 @@ panel_applet_item_handler_get_object (BonoboItemHandler *handler,
 				bonobo_pbclient_set_short (
 					BONOBO_OBJREF (applet->priv->prop_sack), PROPERTY_SIZE,
 					GNOME_Vertigo_PANEL_XX_LARGE, NULL);
+		} else if (!strcmp (option->key, "locked_down")) {
+			gboolean val = FALSE;
+			if (option->value[0] == 'T' ||
+			    option->value[0] == 't' ||
+			    option->value[0] == 'Y' ||
+			    option->value[0] == 'y' ||
+			    atoi (option->value) != 0)
+				val = TRUE;
+			bonobo_pbclient_set_boolean (BONOBO_OBJREF (applet->priv->prop_sack),
+						     PROPERTY_LOCKED_DOWN, val, NULL);
 		}
 	}
 
